@@ -9,8 +9,8 @@
 #
 # See the LICENSE file in the source distribution for further information.
 
-from sos.report.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 import os
+from sos.report.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
 
 class OpenStackIronic(Plugin):
@@ -22,6 +22,8 @@ class OpenStackIronic(Plugin):
 
     var_puppet_gen = "/var/lib/config-data/puppet-generated/ironic"
     ins_puppet_gen = var_puppet_gen + "_inspector"
+    conf_list = []
+    osc_available = False
 
     def setup(self):
 
@@ -69,9 +71,10 @@ class OpenStackIronic(Plugin):
             for path in ['/var/lib/ironic', '/httpboot', '/tftpboot',
                          self.ins_puppet_gen + '/var/lib/httpboot/',
                          self.ins_puppet_gen + '/var/lib/tftpboot/']:
-                self.add_cmd_output('ls -laRt %s' % path)
-                self.add_cmd_output('ls -laRt %s' %
-                                    (self.var_puppet_gen + path))
+                self.add_dir_listing([
+                    path,
+                    f"{self.var_puppet_gen}{path}"
+                ], recursive=True)
 
             # Let's get the packages from the containers, always helpful when
             # troubleshooting.
@@ -107,8 +110,12 @@ class OpenStackIronic(Plugin):
                     "/var/log/ironic-inspector/*.log",
                 ])
 
-            for path in ['/var/lib/ironic', '/httpboot', '/tftpboot']:
-                self.add_cmd_output('ls -laRt %s' % path)
+            self.add_dir_listing(['/var/lib/ironic', '/httpboot', '/tftpboot'],
+                                 recursive=True)
+
+        self.add_file_tags({
+            ".*/etc/ironic/ironic.conf": "ironic_conf"
+        })
 
         vars_all = [p in os.environ for p in [
                     'OS_USERNAME', 'OS_PASSWORD']]
@@ -129,6 +136,7 @@ class OpenStackIronic(Plugin):
             self.add_cmd_output("openstack baremetal port group list --long")
 
     def apply_regex_sub(self, regexp, subst):
+        """ Apply regex substitution """
         for conf in self.conf_list:
             self.do_path_regex_sub(conf, regexp, subst)
 
@@ -140,13 +148,14 @@ class OpenStackIronic(Plugin):
         ]
         connection_keys = ["connection", "sql_connection"]
 
+        join_con_keys = "|".join(connection_keys)
+
         self.apply_regex_sub(
-            r"((?m)^\s*(%s)\s*=\s*)(.*)" % "|".join(protect_keys),
+            fr"(^\s*({'|'.join(protect_keys)})\s*=\s*)(.*)",
             r"\1*********"
         )
         self.apply_regex_sub(
-            r"((?m)^\s*(%s)\s*=\s*(.*)://(\w*):)(.*)(@(.*))" %
-            "|".join(connection_keys),
+            fr"(^\s*({join_con_keys})\s*=\s*(.*)://(\w*):)(.*)(@(.*))",
             r"\1*********\6"
         )
 
@@ -155,9 +164,6 @@ class DebianIronic(OpenStackIronic, DebianPlugin, UbuntuPlugin):
 
     packages = ('ironic-api', 'ironic-common', 'ironic-conductor')
 
-    def setup(self):
-        super(DebianIronic, self).setup()
-
 
 class RedHatIronic(OpenStackIronic, RedHatPlugin):
 
@@ -169,6 +175,7 @@ class RedHatIronic(OpenStackIronic, RedHatPlugin):
     ]
 
     def collect_introspection_data(self):
+        """ Capture baremetal introspection data """
         uuids_result = self.collect_cmd_output(
             'openstack baremetal node list -f value -c UUID'
         )
@@ -181,14 +188,14 @@ class RedHatIronic(OpenStackIronic, RedHatPlugin):
                  if uuid.strip()]
         for uuid in uuids:
             self.add_cmd_output('openstack baremetal introspection '
-                                'data save %s' % uuid)
+                                f'data save {uuid}')
 
     def setup(self):
-        super(RedHatIronic, self).setup()
+        super().setup()
 
         # ironic-discoverd was renamed to ironic-inspector in Liberty
         # is the optional ironic-discoverd service installed?
-        if any([self.is_installed(p) for p in self.discoverd_packages]):
+        if any(self.is_installed(p) for p in self.discoverd_packages):
             self.conf_list.append('/etc/ironic-discoverd/*')
             self.add_copy_spec('/etc/ironic-discoverd/')
             self.add_copy_spec('/var/lib/ironic-discoverd/')
